==> pokerth_0.5+dfsg.orig.tar.gz: pokerth-0.5+dfsg/src/gui/qt/aboutpokerth/aboutpokerthimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ABOUTPOKERTHIMPL_H
#define ABOUTPOKERTHIMPL_H

#include "ui_aboutpokerth.h"


class aboutPokerthImpl: public QDialog, public Ui::aboutPokerth {
Q_OBJECT
public:
    aboutPokerthImpl(QWidget *parent = 0);
};

#endif

==> pokerth_0.8.2-4.tar.gz: pokerth-0.8.2/src/gui/qt/aboutpokerth/aboutpokerthimpl.h <==
/***************************************************************************
 *   Copyright (C) 2006 by FThauer FHammer   *
 *   f.thauer@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ABOUTPOKERTHIMPL_H
#define ABOUTPOKERTHIMPL_H

//--- GUI_800x480 ---
#include "ui_aboutpokerth_800x480.h"
//---
// #include "ui_aboutpokerth.h"
//---

class ConfigFile;

class aboutPokerthImpl: public QDialog, public Ui::aboutPokerth {
Q_OBJECT
public:
    aboutPokerthImpl(QWidget *parent = 0, ConfigFile *c =0);

private:

	ConfigFile *myConfig;
	QString myAppDataPath;
};

#endif
